@@ -20,13 +20,13 @@ class Execo(Engine):
     def __init__(self, persistence_dir: Path):
         self.sweeper = ParamSweeper(str(persistence_dir))
 
-    def get_next(self) -> Param:
+    def next(self) -> Param:
         return self.sweeper.get_next()
 
-    def done(self, param: Param):
+    def ack(self, param: Param):
         self.sweeper.done(param)
 
-    def skip(self, param: Param):
+    def nack(self, param: Param):
         self.sweeper.skip(param)
 
     @classmethod
